data states_capitals; /*Create dataset of all States and their Capitals*/
input state $15. capital $30.;
datalines;
Alabama 		Montgomery
Alaska 			Juneau
Arizona 		Phoenix
Arkansas 		Little Rock
California 		Sacramento
Colorado 		Denver
Connecticut 	Hartford
Delaware 		Dover
Florida 		Tallahassee
Georgia 		Atlanta
Hawaii 			Honolulu
Idaho 			Boise
Illinois 		Springfield
Indiana 		Indianapolis
Iowa 			Des Moines
Kansas 			Topeka
Kentucky 		Frankfort
Louisiana 		Baton Rouge
Maine 			Augusta
Maryland 		Annapolis
Massachusetts 	Boston
Michigan 		Lansing
Minnesota 		St. Paul
Mississippi 	Jackson
Missouri 		Jefferson City
Montana 		Helena
Nebraska 		Lincoln
Nevada 			Carson City
New Hampshire 	Concord
New Jersey 		Trenton
New Mexico 		Santa Fe
New York 		Albany
North Carolina 	Raleigh
North Dakota 	Bismarck
Ohio 			Columbus
Oklahoma 		Oklahoma City
Oregon 			Salem
Pennsylvania 	Harrisburg
Rhode Island 	Providence
South Carolina 	Columbia
South Dakota 	Pierre
Tennessee 		Nashville
Texas 			Austin
Utah 			Salt Lake City
Vermont 		Montpelier
Virginia 		Richmond
Washington 		Olympia
West Virginia 	Charleston
Wisconsin 		Madison
Wyoming 		Cheyenne
;
run;

%macro update(num); /*Updating Macro*/

libname file&num. EXCEL "C:\Data\SAS Paper\Example &num..xlsx" header=yes mixed=yes; /*Readin Excel file using LIBNAME*/

data file&num.;
set file&num.."ENTRY$"n;
run;

libname file&num. clear;

options noxwait noxsync; 

x "START EXCEL"; /*Open Excel*/
data _null_;
x = sleep(3);
run;

filename cmds dde 'EXCEL|SYSTEM';

data _null_; /*Open Excel file with pre-programmed VBA macro*/
file cmds;
put '[FILE-OPEN("C:\Data\SAS Paper\Macro.xlsb")]';
run;

data _null_; /*Open file that needs to be updated*/
file cmds;
string = '[FILE-OPEN("'||"C:\Data\SAS Paper\Example &num..xlsx"||'")]';
put string;
run;

data _null_; /*Create new worksheet*/
file cmds;
put '[WORKBOOK.NEXT()]';
put '[WORKBOOK.INSERT()]';
run;

filename sheet dde "EXCEL|Sheet1!R1C1:R100C1000" notab; 

data _null_; /*Print States and Capitals information to new worksheet in Excel*/
set states_capitals;
file sheet lrecl=1000 notab dsd dlm='09'x;
put state capital;
run;

data _null_;
file cmds;
put '[RUN("MACRO.XLSB!MACRO1")]'; /*Run VBA Macro*/
put '[ERROR(FALSE)]';
put '[WORKBOOK.SELECT("ENTRY")]';
put '[SELECT("C4")]'; /*Select field that was updated that has the VLOOKUP formula*/
put '[COPY()]'; /*Copy field that was updated that has the VLOOKUP formula*/
put '[PASTE.SPECIAL(3)]'; /*Paste Values in same field to overwrite the VLOOKUP formula*/
put '[ERROR(FALSE)]';
put '[WORKBOOK.DELETE("Sheet1")]';
put '[SELECT("R1C1")]';
X = SLEEP(1) ;
run;

data _null_; /*Save Excel file and quit*/
file cmds;
put '[WORKBOOK.ACTIVATE("ENTRY")]';
put '[ERROR(FALSE)]';
string = '[SAVE.AS("'||"C:\Data\SAS Paper\Example &num. Updated.xlsx"||'")]';
put string;
put '[QUIT()]';
run;
%mend update;

%update(1); /*File 1*/
%update(2); /*File 2*/
